@@ -1,4 +1,10 @@
+#!/usr/bin/env python
+
+import sys
 from fnmatch import fnmatch
+from pkg_resources import iter_entry_points
+
+### abstract base classes for formatters
 
 class FormatterBase(object):
     """
@@ -7,21 +13,27 @@ class FormatterBase(object):
     'arg1, arg2, arg3, kw1=foo, kw2=bar, kw3=baz
     """
 
-    defaults = {}
+    defaults = {} # default values for attrs to be set on the instance
+    
 
     def __init__(self, string):
-        args = [ i.strip() for i in string.split(',') ]
+        args = [ i.strip() for i in string.split(',')]
         for index, arg in enumerate(args):
             if '=' in arg:
                 break
         else:
             self.args = args
+            for key, default in self.defaults.items():
+                setattr(self, key, default)
             return
         self.args = args[:index]
         self.kw = dict([i.split('=', 1) for i in args[index:]])
-        for key, default in defaults.items():
-            if key not in self.kw:
-                self.kw[key] = default
+        for key, default in self.defaults.items():
+            value = self.kw.pop(key, default)
+            setattr(self, key, value)
+
+
+### formatters
 
 class Ignore(object):
     """ignore files of a certain pattern"""
@@ -44,7 +56,7 @@ class Ignore(object):
 
 class All(object):
     """
-    only pass files of a certain pattern;
+    only pass files of a certain pattern; 
     the inverse of ignore
     """
     
@@ -69,6 +81,7 @@ class All(object):
         
 
 class FilenameDescription(FormatterBase):
+    """substitute the description for the filename"""
 
     def __call__(self, request, data):
         for f in data['files']:
@@ -80,6 +93,9 @@ class FilenameDescription(FormatterBase):
 
 
 class TitleDescription(FormatterBase):
+    """splits a description into a title and a description with a separator"""
+    
+
     defaults = { 'separator': ':' }
         
     def __call__(self, request, data):
@@ -91,5 +107,21 @@ class TitleDescription(FormatterBase):
             else:
                 f['title'] = f['description']
                 f['description'] = None
-                
+
         
+def formatters():
+    formatters = {}
+    for entry_point in iter_entry_points('decoupage.formatters'):
+        try:
+            formatter = entry_point.load()
+        except:
+            continue
+        formatters[entry_point.name] = formatter
+    return formatters
+
+def main(args=sys.argv[1:]):
+    for name, formatter in formatters().items():
+        print '%s%s' % (name, formatter.__doc__ and ': ' + formatter.__doc__ or '')
+
+if __name__ == '__main__':
+    main()
